=================
django-autoconfig
=================


.. image:: https://travis-ci.org/mikebryant/django-autoconfig.png?branch=master
    :target: https://travis-ci.org/mikebryant/django-autoconfig
    :alt: Build Status Badge
.. image:: https://coveralls.io/repos/mikebryant/django-autoconfig/badge.png?branch=master
    :target: https://coveralls.io/r/mikebryant/django-autoconfig?branch=master
    :alt: Coverage Status Badge
.. image:: https://landscape.io/github/mikebryant/django-autoconfig/master/landscape.png
   :target: https://landscape.io/github/mikebryant/django-autoconfig/master
   :alt: Code Health Badge
.. image:: https://pypip.in/v/django-autoconfig/badge.png
    :target: https://pypi.python.org/pypi/django-autoconfig/
    :alt: Version Badge
.. image:: https://pypip.in/d/django-autoconfig/badge.png
    :target: https://pypi.python.org/pypi/django-autoconfig/
    :alt: Downloads Badge
.. image:: https://pypip.in/wheel/django-autoconfig/badge.png
    :target: https://pypi.python.org/pypi/django-autoconfig/
    :alt: Wheel Status Badge
.. image:: https://pypip.in/license/django-autoconfig/badge.png
    :target: https://pypi.python.org/pypi/django-autoconfig/
    :alt: License Badge

Automatic configuration of Django projects based on the requirements of apps in the INSTALLED_APP setting.

Official docs can be found at `Read the Docs`_.

.. _`Read the Docs`: https://django-autoconfig.readthedocs.org
